==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/vyroba/cinnostdennivyroby.php <==
<?php
/**
 * stanislav.elbl, 11.09.2018
 */

namespace RonPortal\Vyroba;

use Ron\DB\Database;
use Ron\DB\Parameters;
use Ron\StringUtils;
use RonPortal\PracovniPomer;


/**
 * Seznam cinnosti vyroby - nacita se bud z tabulky VyrobniCinnost nebo z CinnostVyrobniZakazky (podle nastaveni)
 * Class CinnostDenniVyroby
 * @package Ron\RonPortal\Vyroba
 */
class CinnostDenniVyroby
{
    public $kod;
    public $popis;

    /** @var int        Vazba do tabulky CinnostVyrobniZakazky */
    public $cinnostVyrobniZakazky;
    /** @var string     Kod Zakazky, ke ktere je cinnost prirazena */
    public $cisloZakazky;

    /** @var int */
    public $datumCasOd;
    /** @var int */
    public $datumCasDo;

    /**
     * @param Database $database
     * @param string $sql
     * @param Parameters $params
     * @return CinnostDenniVyroby[]
     */
    private static function nactiCinnostiSQL($database, $sql, $params)
    {
        $cursor = $database ->getSqlResult($sql, $params);
        $result = [];
        while ($row = $cursor ->fetch()) {
            $cinnost = new static();

            $cinnost ->kod = $row[0];
            $cinnost ->popis = $row[1];

            if (isset($row[2])) {
                $cinnost->cinnostVyrobniZakazky = $row[2];
                $cinnost->cisloZakazky = $row[3];

                $cinnost->datumCasOd = isset($row[4]) ? $database->stringToTimestamp($row[4]) : null;
                $cinnost->datumCasDo = isset($row[5]) ? $database->stringToTimestamp($row[5]) : null;
            }

            $result[] = $cinnost;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * Vraci seznam aktivnich vyrobnich cinnosti
     * @param Database $database
     * @return CinnostDenniVyroby[]
     */
    public static function nactiVyrobniCinnosti($database)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT VyrobniCinnost.Kod, VyrobniCinnost.Popis' .
            ' FROM VyrobniCinnost' .
            ' WHERE Aktivni = 1' .
            ' ORDER by Popis';

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * Vraci seznam aktivnich vyrobnich cinnosti
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param string $zakazka
     * @return CinnostDenniVyroby[]
     */
    public static function nactiPrirazeneCinnosti($database, $pp, $datumOd, $datumDo = null, $zakazka = null)
    {
        if (!$datumDo) $datumDo = $datumOd;

        $params = $database ->createParameters();

        $sql =
            'SELECT' .
            '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
            '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
            ' FROM CinnostVyrobniZakazky, PracovnikCinnostiZakazky, VyrobniZakazka' .
            ' WHERE PracovnikCinnostiZakazky.CinnostVyrobniZakazky_ID = CinnostVyrobniZakazky.Id' .
            ' AND PracovnikCinnostiZakazky.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND PracovnikCinnostiZakazky.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND PracovnikCinnostiZakazky.DatumNastupu = ' . $params ->addParameter($database ->dateToParam($pp ->datumNastupu)) .
            ' AND CinnostVyrobniZakazky.CisloZakazky = VyrobniZakazka.CisloZakazky' .
            ' AND (VyrobniZakazka.PlatnostOd IS NULL  OR  VyrobniZakazka.PlatnostOd <= ' . $params ->addParameter($database ->dateToParam($datumDo)) . ')' .
            ' AND (VyrobniZakazka.PlatnostDo IS NULL  OR  VyrobniZakazka.PlatnostDo >= ' . $params ->addParameter($database ->dateToParam($datumOd)) . ')' .
            ' AND (CinnostVyrobniZakazky.DatumCasOd IS NULL  OR  CinnostVyrobniZakazky.DatumCasOd <= ' . $params ->addParameter($database ->dateToParam($datumDo)) . ')' .
            ' AND (CinnostVyrobniZakazky.DatumCasDo IS NULL  OR  CinnostVyrobniZakazky.DatumCasDo >= ' . $params ->addParameter($database ->dateToParam($datumOd)) . ')'
            ;

        if ($zakazka) {
            $sql .= ' AND CinnostVyrobniZakazky.CisloZakazky = ' . $params ->addParameter($zakazka);
        }

        $sql .= ' ORDER BY CinnostVyrobniZakazky.Popis';

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * @param Database $database
     * @param int $id
     * @return CinnostDenniVyroby
     * @throws \Exception
     */
    public static function vratCinnostVyrobniZakazky($database, $id)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT' .
            '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
            '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
            ' FROM CinnostVyrobniZakazky' .
            ' WHERE CinnostVyrobniZakazky.Id = ' . $params ->addParameter($id);

        $sql .= ' ORDER BY CinnostVyrobniZakazky.Popis';

        $data = static::nactiCinnostiSQL($database, $sql, $params);
        if (!$data  ||  !count($data)) {
            throw new \Exception( StringUtils::fromUTF8("Nenalezena cinnost vyrobni zakazky (id = $id)!"));
        }

        return $data[0];
    }

    /**
     * Nacte seznam vsech cinnosti, ktere zadany pracovni pomer vykazal v zadanem obdobi
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $jenPrirazeneCinnosti    Urcuje, jestli se nacita z tabulky CinnostVyrobniZakazky, nebo primo z VyrobniCinnost
     * @return CinnostDenniVyroby[]
     */
    public static function nactiCinnostiVObdobi($database, $pp, $datumOd, $datumDo, $jenPrirazeneCinnosti)
    {
        $params = $database ->createParameters();

        if ($jenPrirazeneCinnosti) {
            $sql =
                'SELECT DISTINCT' .
                '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
                '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
                ' FROM Vyroba, CinnostVyrobniZakazky' .
                ' WHERE Vyroba.CinnostVyrobniZakazky = CinnostVyrobniZakazky.Id' .
                ' AND Vyroba.Den >= ' . $params->addParameter($database->dateToParam($datumOd)) .
                ' AND Vyroba.Den <= ' . $params->addParameter($database->dateToParam($datumDo)) .
                ' AND Vyroba.RC = ' . $params->addParameter($pp->rc) .
                ' AND Vyroba.OsobniCislo = ' . $params->addParameter($pp->osobniCislo) .
                ' AND Vyroba.DatumNastupu = ' . $params->addParameter($database->dateToParam($pp->datumNastupu)) .
                ' ORDER BY CinnostVyrobniZakazky.Popis';
        } else {
            $sql =
                'SELECT DISTINCT' .
                '  VyrobniCinnost.Kod, VyrobniCinnost.Popis, null, null, ' . // 0..3
                '  null, null' . // 4,5
                ' FROM Vyroba, VyrobniCinnost' .
                ' WHERE Vyroba.Cinnost = VyrobniCinnost.Kod' .
                ' AND Vyroba.Den >= ' . $params->addParameter($database->dateToParam($datumOd)) .
                ' AND Vyroba.Den <= ' . $params->addParameter($database->dateToParam($datumDo)) .
                ' AND Vyroba.RC = ' . $params->addParameter($pp->rc) .
                ' AND Vyroba.OsobniCislo = ' . $params->addParameter($pp->osobniCislo) .
                ' AND Vyroba.DatumNastupu = ' . $params->addParameter($database->dateToParam($pp->datumNastupu)) .
                ' ORDER BY VyrobniCinnost.Popis';
        }

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * K zadane cinnosti vyrobni zakazky (id) najde kod cinnosti
     * @param Database $database
     * @param int $id
     * @return string
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    public static function vratKodCinnostiVyrobniZakazky($database, $id)
    {
        $params = $database ->createParameters();
        $sql = 'SELECT KodCinnosti FROM CinnostVyrobniZakazky WHERE Id = ' . $params ->addParameter($id);

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        if (!$row) {
            throw new \Exception( "Nenalezena cinnost vyrobni zakazky (id = $id)!");
        }

        return $row[0];
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/vyroba/cinnostdennivyroby.php <==
<?php
/**
 * stanislav.elbl, 11.09.2018
 */

namespace RonPortal\Vyroba;

use Ron\DB\Database;
use Ron\DB\Parameters;
use Ron\StringUtils;
use RonPortal\PracovniPomer;


/**
 * Seznam cinnosti vyroby - nacita se bud z tabulky VyrobniCinnost nebo z CinnostVyrobniZakazky (podle nastaveni)
 * Class CinnostDenniVyroby
 * @package Ron\RonPortal\Vyroba
 */
class CinnostDenniVyroby
{
    public $kod;
    public $popis;

    /** @var int        Vazba do tabulky CinnostVyrobniZakazky */
    public $cinnostVyrobniZakazky;
    /** @var string     Kod Zakazky, ke ktere je cinnost prirazena */
    public $cisloZakazky;

    /** @var int */
    public $datumCasOd;
    /** @var int */
    public $datumCasDo;

    /**
     * @param Database $database
     * @param string $sql
     * @param Parameters $params
     * @return CinnostDenniVyroby[]
     */
    private static function nactiCinnostiSQL($database, $sql, $params)
    {
        $cursor = $database ->getSqlResult($sql, $params);
        $result = [];
        while ($row = $cursor ->fetch()) {
            $cinnost = new static();

            $cinnost ->kod = $row[0];
            $cinnost ->popis = $row[1];

            if (isset($row[2])) {
                $cinnost->cinnostVyrobniZakazky = $row[2];
                $cinnost->cisloZakazky = $row[3];

                $cinnost->datumCasOd = isset($row[4]) ? $database->stringToTimestamp($row[4]) : null;
                $cinnost->datumCasDo = isset($row[5]) ? $database->stringToTimestamp($row[5]) : null;
            }

            $result[] = $cinnost;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * Vraci seznam aktivnich vyrobnich cinnosti
     * @param Database $database
     * @return CinnostDenniVyroby[]
     */
    public static function nactiVyrobniCinnosti($database)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT VyrobniCinnost.Kod, VyrobniCinnost.Popis' .
            ' FROM VyrobniCinnost' .
            ' WHERE Aktivni = 1' .
            ' ORDER by Popis';

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * Vraci seznam aktivnich vyrobnich cinnosti
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param string $zakazka
     * @return CinnostDenniVyroby[]
     */
    public static function nactiPrirazeneCinnosti($database, $pp, $datumOd, $datumDo = null, $zakazka = null, $cinnost = null)
    {
        if (!$datumDo) {
            $datumDo = $datumOd;
        }

        $params = $database ->createParameters();

        $sql =
            'SELECT' .
            '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
            '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
            ' FROM CinnostVyrobniZakazky, PracovnikCinnostiZakazky, VyrobniZakazka' .
            ' WHERE PracovnikCinnostiZakazky.CinnostVyrobniZakazky_ID = CinnostVyrobniZakazky.Id' .
            ' AND PracovnikCinnostiZakazky.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND PracovnikCinnostiZakazky.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND PracovnikCinnostiZakazky.DatumNastupu = ' . $params ->addDateParameter($pp ->datumNastupu) .
            ' AND CinnostVyrobniZakazky.CisloZakazky = VyrobniZakazka.CisloZakazky' .
            ' AND (VyrobniZakazka.PlatnostOd IS NULL  OR  VyrobniZakazka.PlatnostOd <= ' . $params ->addDateParameter($datumDo) . ')' .
            ' AND (VyrobniZakazka.PlatnostDo IS NULL  OR  VyrobniZakazka.PlatnostDo >= ' . $params ->addDateParameter($datumOd) . ')' .
            ' AND (CinnostVyrobniZakazky.DatumCasOd IS NULL  OR  CinnostVyrobniZakazky.DatumCasOd <= ' . $params ->addDateParameter($datumDo) . ')' .
            ' AND (CinnostVyrobniZakazky.DatumCasDo IS NULL  OR  CinnostVyrobniZakazky.DatumCasDo >= ' . $params ->addDateParameter($datumOd) . ')'
            ;

        if ($zakazka) {
            $sql .= ' AND CinnostVyrobniZakazky.CisloZakazky = ' . $params ->addParameter($zakazka);
        }

        if ($cinnost) {
            // slouzi pro kontrolu, jestli je cinnost povolena (tj. jestli ji pracovnik na dane zakazce muze vykonavat)
            $sql .= ' AND CinnostVyrobniZakazky.KodCinnosti = ' . $params ->addParameter($cinnost);
        }

        $sql .= ' ORDER BY CinnostVyrobniZakazky.Popis';

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * Zjisti, jestli muze pracovnik ($pp) na zakazce $zakazka vykonavat $cinnost
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datum
     * @param string $zakazka
     * @param string $cinnost
     * @return bool
     */
    public static function jeCinnostPovolena($database, $pp, $datum, $zakazka, $cinnost)
    {
        $cinnosti = self::nactiPrirazeneCinnosti($database, $pp, $datum, $datum, $zakazka, $cinnost);
        return (bool)$cinnosti;
    }


    /**
     * @param Database $database
     * @param int $id
     * @return CinnostDenniVyroby
     * @throws \Exception
     */
    public static function vratCinnostVyrobniZakazky($database, $id)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT' .
            '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
            '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
            ' FROM CinnostVyrobniZakazky' .
            ' WHERE CinnostVyrobniZakazky.Id = ' . $params ->addParameter($id);

        $sql .= ' ORDER BY CinnostVyrobniZakazky.Popis';

        $data = static::nactiCinnostiSQL($database, $sql, $params);
        if (!$data  ||  !count($data)) {
            throw new \Exception( StringUtils::fromUTF8("Nenalezena cinnost vyrobni zakazky (id = $id)!"));
        }

        return $data[0];
    }

    /**
     * Nacte seznam vsech cinnosti, ktere zadany pracovni pomer vykazal v zadanem obdobi
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $jenPrirazeneCinnosti    Urcuje, jestli se nacita z tabulky CinnostVyrobniZakazky, nebo primo z VyrobniCinnost
     * @return CinnostDenniVyroby[]
     */
    public static function nactiCinnostiVObdobi($database, $pp, $datumOd, $datumDo, $jenPrirazeneCinnosti)
    {
        $params = $database ->createParameters();

        if ($jenPrirazeneCinnosti) {
            $sql =
                'SELECT DISTINCT' .
                '  CinnostVyrobniZakazky.KodCinnosti, CinnostVyrobniZakazky.Popis, CinnostVyrobniZakazky.Id, CinnostVyrobniZakazky.CisloZakazky, ' . // 0..3
                '  CinnostVyrobniZakazky.DatumCasOd, CinnostVyrobniZakazky.DatumCasDo' . // 4,5
                ' FROM Vyroba, CinnostVyrobniZakazky' .
                ' WHERE Vyroba.CinnostVyrobniZakazky = CinnostVyrobniZakazky.Id' .
                ' AND Vyroba.Den >= ' . $params->addParameter($database->dateToParam($datumOd)) .
                ' AND Vyroba.Den <= ' . $params->addParameter($database->dateToParam($datumDo)) .
                ' AND Vyroba.RC = ' . $params->addParameter($pp->rc) .
                ' AND Vyroba.OsobniCislo = ' . $params->addParameter($pp->osobniCislo) .
                ' AND Vyroba.DatumNastupu = ' . $params->addParameter($database->dateToParam($pp->datumNastupu)) .
                ' ORDER BY CinnostVyrobniZakazky.Popis';
        } else {
            $sql =
                'SELECT DISTINCT' .
                '  VyrobniCinnost.Kod, VyrobniCinnost.Popis, null, null, ' . // 0..3
                '  null, null' . // 4,5
                ' FROM Vyroba, VyrobniCinnost' .
                ' WHERE Vyroba.Cinnost = VyrobniCinnost.Kod' .
                ' AND Vyroba.Den >= ' . $params->addParameter($database->dateToParam($datumOd)) .
                ' AND Vyroba.Den <= ' . $params->addParameter($database->dateToParam($datumDo)) .
                ' AND Vyroba.RC = ' . $params->addParameter($pp->rc) .
                ' AND Vyroba.OsobniCislo = ' . $params->addParameter($pp->osobniCislo) .
                ' AND Vyroba.DatumNastupu = ' . $params->addParameter($database->dateToParam($pp->datumNastupu)) .
                ' ORDER BY VyrobniCinnost.Popis';
        }

        return static::nactiCinnostiSQL($database, $sql, $params);
    }


    /**
     * K zadane cinnosti vyrobni zakazky (id) najde kod cinnosti
     * @param Database $database
     * @param int $id
     * @return string
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    public static function vratKodCinnostiVyrobniZakazky($database, $id)
    {
        $params = $database ->createParameters();
        $sql = 'SELECT KodCinnosti FROM CinnostVyrobniZakazky WHERE Id = ' . $params ->addParameter($id);

        $cursor = $database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        if (!$row) {
            throw new \Exception( "Nenalezena cinnost vyrobni zakazky (id = $id)!");
        }

        return $row[0];
    }
}
